@@ -312,7 +312,7 @@ class DictizableMixin(object):
             rels_to_expand=rels_to_expand, rels_to_serialize=rels_to_serialize,
             key_modifications=key_modifications)
 
-    def todict_using_struct(self, dict_struct=None, dict_post_processors=None):
+    def todict_using_struct(self, dict_struct=None, dict_post_processors=None, key_modifications=None):
         """
             dict_struct:
             {
@@ -359,6 +359,10 @@ class DictizableMixin(object):
             for dict_post_processor in dict_post_processors:
                 if callable(dict_post_processor):
                     result = dict_post_processor(result, self)
+        if key_modifications is not None:
+            for key, mod_key in key_modifications.items():
+                if key in result:
+                    result[mod_key] = result.pop(key)
         return result
 
 
@@ -410,10 +414,14 @@ class DictizableMixin(object):
             else dict_struct)
         if dict_struct is None:
             dict_struct = self.autogenerated_dict_structure()
+        key_modifications = (
+            self._key_modifications_ if key_modifications is None
+            else key_modifications)
         if dict_struct is not None:
             return self.todict_using_struct(
                 dict_struct=dict_struct,
-                dict_post_processors=dict_post_processors)
+                dict_post_processors=dict_post_processors,
+                key_modifications=key_modifications)
         attrs_to_serialize = (
             self._attrs_to_serialize_ if attrs_to_serialize is None
             else attrs_to_serialize)
@@ -423,9 +431,6 @@ class DictizableMixin(object):
         rels_to_expand = (
             self._rels_to_expand_ if rels_to_expand is None
             else rels_to_expand)
-        key_modifications = (
-            self._key_modifications_ if key_modifications is None
-            else key_modifications)
         group_listrels_by = (
             self._group_listrels_by_ if group_listrels_by is None
             else group_listrels_by)
@@ -511,7 +516,6 @@ class DictizableMixin(object):
                     result[rel] = rel_obj.todict(
                         rels_to_expand=child_rels) if hasattr(
                         rel_obj, 'todict') else rel_obj
-
         for key, mod_key in key_modifications.items():
             if key in result:
                 result[mod_key] = result.pop(key)
